/**
 * Custom Links Widget
 */
.oceanwp-custom-links {
	list-style: none;
	margin: 0;
	padding: 0;

	li {
		padding: 2px 0;

		a {
			display: inline-block;
		    position: relative;
		    font-size: 13px;
			color: $color-2;

			&:before {
				content: '\f111';
			    display: inline-block;
			    color: $color-4;
			    font-size: 10px;
			    margin-right: 10px;
			    margin-top: -2px;
			    font-family: 'Font Awesome 5 Free';
			    font-weight: 400;
			    vertical-align: middle;
			    zoom: 1;
			}

			&:hover {
				margin-left: 8px;
				color: $color-5;
			}

			&:hover:before {
				color: $color-5;
			}
		}

		&:first-child {
			padding-top: 0;
		}
	}
}