/**
 * MailChimp Widget
 */
.oceanwp-newsletter-form-wrap {
    position: relative;

    .oceanwp-mail-text {
	    margin-bottom: 10px;
	}

	form {
		position: relative;
		max-width: 100%;
    	margin: 0 auto;
	}

	input[type="email"] {
	    height: 50px;
	    padding: 0 15px;
	    margin: 0;
	}

	button {
	    display: block;
	    position: absolute;
	    top: 50%;
	    right: 15px;
	    padding: 0 15px;
	    height: 60%;
	    border-radius: 3px;
	    -ms-transform: translateY(-50%);
	    -webkit-transform: translateY(-50%);
	    transform: translateY(-50%);
	}
}

#mc-embedded-subscribe-form {
	.email-wrap {
		position: relative;
		margin-bottom: 10px;
	}

	.gdpr-wrap {
		label,
		.err-msg{
			display: block;
		}
	}

	.err-msg,
	.res-msg {
		display: block;
		padding: 3px 13px;
		margin-bottom: 10px;
		border: 1px solid transparent;
		border-radius: 4px;
	}

	.err-msg,
	.failed.res-msg {
		color: #a94442;
		background-color: #f2dede;
		border-color: #ebccd1;
	}

	.success.res-msg {
		color: #3c763d;
		background-color: #dff0d8;
		border-color: #d6e9c6;
	}

	.success.res-msg,
	.failed.res-msg {
		margin: 6px 0 0;
	}
}

/* Prevent conflict with woocommerce */
body.woocommerce .oceanwp-newsletter-form-wrap button {
	padding-top: 0 !important;
    padding-bottom: 0 !important;
}