/**
 * Flickr Widget
 */
.oceanwp-flickr-wrap .flickr_badge_image {
	float: left;
    margin: 0 4% 10px 0;
    width: 30.6%;
    transition: all .3s ease;

    &:hover {
	    opacity: 0.8;
	}

    &#flickr_badge_image3,
    &#flickr_badge_image6,
    &#flickr_badge_image9 {
    	margin-right: 0;
    }

	a {
		border: none;
	}

	img {
		margin: 0;
		overflow: hidden;
		position: relative;
		width: 100%;
		height: 100%;
		max-width: 100%;
		max-height: 100%;
	}
}

p.flickr_stream_wrap {
	display: inline-block;
    width: 100%;
	margin-top: 10px;
	margin-bottom: 0;
	font-size: 90%;
	line-height: 1;
    letter-spacing: 0.6px;

	a {
		display: inline-block;
		background-image: url('../../assets/img/flickr.png');
		background-repeat: no-repeat;
		background-position: left center;
		padding-left: 25px;
	}
}

/*------------------------------------*
	Phone Landscape
*------------------------------------*/
@media only screen and (max-width: 480px) {

	/* flickr widget */
	.oceanwp-flickr-wrap .flickr_badge_image {
		width: 23%;
	}

}