/**
 * Calendar Widget
 */
#wp-calendar {
	position: relative;
    width: 100%;
	font-size: 12px;
	border-collapse: collapse;
	border-spacing: 0;
	margin: 0;
	border: 0;

	caption {
		font-family: 'Montserrat', sans-serif;
		font-size: 13px;
		font-weight: 400;
		padding-bottom: 10px;
		padding: 0 0 10px 0;
		background-color: transparent;
		color: $color-5;
		border-width: 0 0 3px 0;
		border-style: solid;
		border-color: $border-color;
		text-align: center;
		text-transform: uppercase;
	}

	td, th {
	    text-align: center;
	}

	th {
		font-family: 'Open Sans';
		font-size: 12px;
		font-weight: 400;
		padding: 13px 0px 14px 0px;
		background-color: transparent;
		color: #777;
		border-width: 0 0 1px 0;
		border-style: solid;
		border-color: $border-color;
	}

	tbody {
	    border-width: 0 0 3px 0;
		border-style: solid;
		border-color: $border-color;

		td,
		td:hover,
		td.pad:hover {
			background: transparent;
		}

		td {
		    font-family: 'Open Sans';
			font-size: 12px;
			color: $color-4;
			width: 14.2857%;
			height: 30px;
			line-height: 30px;
			font-weight: 400;
			padding: 5px 0 0 0;
			border: 0;
			vertical-align: middle;
		}

		tr:last-child td {
		    padding-bottom: 10px;
		}

		a, #today {
			font-weight: 600;
		}

		#today {
			color: #111;
		}
	}

	tfoot {
		td {
			background-color: transparent;
			border: 0;
		}

		tr td {
			position: absolute;
			top: -10px;
			font-family: 'Montserrat', sans-serif;
			background-color: transparent !important;
			font-size: 11px;
			padding-top: 10px;
			text-transform: uppercase;

			&#prev, &#next {
				z-index: 10;
			}

			a {
				border-bottom: 1px solid;

				&:hover {
					border-bottom-style: dashed;
				}
			}
		}

		#next {
			right: 0;
		}
	}
}