// Transition
@mixin transition( $args ) {
    -webkit-transition: $args;
    -moz-transition: $args;
    -ms-transition: $args;
    -o-transition: $args;
    transition: $args;
}

// Display inline flex
@mixin display-inline-flex() {
    display: -webkit-inline-flex;
    display: -ms-inline-flex;
    display: inline-flex;
}

// Display flex
@mixin display-flex() {
    display: -webkit-box;
    display: -webkit-flex;
    display: -ms-flexbox;
    display: flex;
}

// Flex wrap
@mixin flex-wrap( $args ) {
    -webkit-flex-wrap: $args;
    -ms-flex-wrap: $args;
    flex-wrap: $args;
}

// Align items
@mixin align-items( $args ) {
    -webkit-align-items: $args;
	-ms-flex-align: $args;
	align-items: $args;
}

// Justify content
@mixin justify-content( $args ) {
	-webkit-justify-content: $args;
	-ms-flex-pack: $args;
	justify-content: $args;
}

// Opacity
@mixin opacity( $args ) {
    -moz-opacity: $args;
    -webkit-opacity: $args;
    opacity: $args;
}

/**
 * Social Share Widget
 */
.owp-social-share {
	margin: 0;
    padding: 0;
    list-style: none;

	li {
		float: left;
	    margin: 0 8px 8px 0;

	    a {
		    @include display-inline-flex();
			@include align-items( center );
			@include justify-content( center );
			position: relative;
			width: 40px;
			height: 40px;
			line-height: 1;
		    border-radius: 30px;
	    	overflow: hidden;

	    	.owpss-icon{
				fill: #fff;
				width: 16px;
				height: 16px;
				@include transition( all 0.3s ease );
	    	}
		}
	}


}

// Minimal style
.owp-social-share.style-minimal {
	li {
		a {
			border: 1px solid #e9e9e9;

			.owpss-icon {
				fill: #bbb;
			}
		}

		&.twitter a:hover {
			color: #00aced;
			border-color: #00aced;

			.owpss-icon {
				fill: #00aced;
			}
		}

		&.facebook a:hover {
			color: #3b5998;
			border-color: #3b5998;

			.owpss-icon {
				fill: #3b5998;
			}
		}

		&.googleplus a:hover {
			color: #dd4b39;
			border-color: #dd4b39;

			.owpss-icon {
				fill: #dd4b39;
			}
		}

		&.linkedin a:hover {
			color: #3399CC;
			border-color: #3399CC;

			.owpss-icon {
				fill: #3399CC;
			}
		}

		&.pinterest a:hover {
			color: #cb2027;
			border-color: #cb2027;

			.owpss-icon {
				fill: #cb2027;
			}
		}

		&.viber a:hover {
			color: #9d62cc;
			border-color: #9d62cc;

			.owpss-icon {
				fill: #9d62cc;
			}
		}

		&.vk a:hover {
			color: #3673be;
			border-color: #3673be;

			.owpss-icon {
				fill: #3673be;
			}
		}

		&.reddit a:hover {
			color: #ff5c1f;
			border-color: #ff5c1f;

			.owpss-icon {
				fill: #ff5c1f;
			}
		}

		&.tumblr a:hover {
			color: #35465c;
			border-color: #35465c;

			.owpss-icon {
				fill: #35465c;
			}
		}

		&.viadeo a:hover {
			color: #ff7452;
			border-color: #ff7452;

			.owpss-icon {
				fill: #ff7452;
			}
		}

		&.whatsapp a:hover {
			color: #128c7e;
			border-color: #128c7e;

			.owpss-icon {
				fill: #128c7e;
			}
		}
	}
}

// Colored style
.owp-social-share.style-colored {
	li {
		a {
			color: #fff;

			&:hover {
				@include opacity( .8 );
			}

			.owpss-icon {
				fill: #fff;
			}
		}

		&.twitter a {
			background-color: #00aced;
		}

		&.facebook a {
			background-color: #3b5998;
		}

		&.googleplus a {
			background-color: #dd4b39;
		}

		&.linkedin a {
			background-color: #3399CC;
		}

		&.pinterest a {
			background-color: #cb2027;
		}

		&.viber a {
			background-color: #9d62cc;
		}

		&.vk a {
			background-color: #3673be;
		}

		&.reddit a {
			background-color: #ff5c1f;
		}

		&.tumblr a {
			background-color: #35465c;
		}

		&.viadeo a {
			background-color: #ff7452;
		}

		&.whatsapp a {
			background-color: #128c7e;
		}
	}
}

// Dark style
.owp-social-share.style-dark {
	li {
		a {
			background-color: #222;
			color: #fff;

			&:hover {
				@include opacity( .8 );
			}

			.owpss-icon {
				fill: #fff;
			}
		}
	}

	&.name-shown .owp-icon-wrap {
		background-color: rgba(255,255,255,.08);
	}
}

// Name Show and Hidden
.owp-social-share.name-shown{
	li{
		a{
			min-width: 144px;
			width: 100%;
		}
	}
}

.owp-social-share.name-shown {
	ul {
	    @include display-flex();
	    @include flex-wrap( wrap );
	    @include justify-content( space-between );

	    li {
			margin: 6px;
			-webkit-box-flex: 1;
		    -moz-box-flex: 1;
		    -webkit-flex: 1;
		    -ms-flex: 1;
		    flex: 1;

			a {
				min-width: 144px;
				width: 100%;
			}
		}
	}

	.owp-icon-wrap {
		display: block;
	    position: absolute;
	    top: 0;
	    bottom: 0;
	    left: 0;
		@include display-inline-flex();
		@include align-items( center );
		@include justify-content( center );
		background-color: rgba(0,0,0,.08);
	    padding: 0 12px;
	    @include transition( all 0.3s ease );
	}

	.owp-social-name {
		display: block;
		width: 100%;
	    padding: 0 10px 0 50px;
	    font-size: 15px;
	    font-weight: 500;
	    text-align: center;
	}

	&.style-minimal li {
		a:hover .owpss-icon {
			fill: #fff !important;
		}

		&.twitter a:hover .owp-icon-wrap {
			background-color: #00aced;
		}

		&.facebook a:hover .owp-icon-wrap {
			background-color: #3b5998;
		}

		&.googleplus a:hover .owp-icon-wrap {
			background-color: #dd4b39;
		}

		&.linkedin a:hover .owp-icon-wrap {
			background-color: #3399CC;
		}

		&.pinterest a:hover .owp-icon-wrap {
			background-color: #cb2027;
		}

		&.viber a:hover .owp-icon-wrap {
			background-color: #9d62cc;
		}

		&.vk a:hover .owp-icon-wrap {
			background-color: #3673be;
		}

		&.reddit a:hover .owp-icon-wrap {
			background-color: #ff5c1f;
		}

		&.tumblr a:hover .owp-icon-wrap {
			background-color: #35465c;
		}

		&.viadeo a:hover .owp-icon-wrap {
			background-color: #ff7452;
		}

		&.whatsapp a:hover .owp-icon-wrap {
			background-color: #128c7e;
		}
	}
}