/**
 * Instagram Widget
 */
.oceanwp-instagram-pics li {
    display: block;
    float: left;
    height: 100%;
    -webkit-transition: all .3s ease;
    -moz-transition: all .3s ease;
    transition: all .3s ease;
}

.oceanwp-instagram-pics.margin li {
    padding: 3px;
}

.oceanwp-instagram-pics li a {
    vertical-align: top;
}

.oceanwp-instagram-pics li img {
    display: block;
    width: 100%;
}

.oceanwp-instagram-pics li:hover {
    opacity: 0.8;
}

/*header*/
.oceanwp-instagram-header {
    position: relative;
    padding: 10px;
}

.oceanwp-instagram-header.oceanwp-left {
    text-align: left;
}

.oceanwp-instagram-header.oceanwp-right {
    text-align: right;
}

.oceanwp-instagram-header.oceanwp-center {
    text-align: center;
}

/*header avatar*/
.oceanwp-instagram-avatar {
    line-height: 1;
}

.oceanwp-instagram-header.oceanwp-left .oceanwp-instagram-avatar {
    float: left;
    margin-right: 10px;
}

.oceanwp-instagram-header.oceanwp-right .oceanwp-instagram-avatar {
    float: right;
    margin-left: 10px;
}

.oceanwp-instagram-header.oceanwp-center .oceanwp-instagram-avatar {
    margin: 0 0 10px;
}

.oceanwp-instagram-avatar a {
    position: relative;
    display: inline-block;
    width: 75px;
    height: 75px;
    overflow: hidden;
}

.oceanwp-instagram-avatar.square a,
.oceanwp-instagram-avatar.square a img {
    -webkit-border-radius: 2px;
    -moz-border-radius: 2px;
    border-radius: 2px;
}

.oceanwp-instagram-avatar.rounded a,
.oceanwp-instagram-avatar.rounded a img {
    -webkit-border-radius: 50%;
    -moz-border-radius: 50%;
    border-radius: 50%;
}

.oceanwp-instagram-avatar a img {
    width: 75px;
    height: 75px;
    -webkit-transition: all .3s ease;
    -moz-transition: all .3s ease;
    transition: all .3s ease;
}

.oceanwp-instagram-avatar a:hover img {
    opacity: 0.5;
}

.oceanwp-instagram-follow {
    position: absolute;
    top: 0;
    margin-top: -12px;
    display: block;
    text-align: center;
    width: 100%;
    opacity: 0;
    -webkit-transition: all ease-out .2s;
    -moz-transition: all ease-out .2s;
    -o-transition: all ease-out .2s;
    transition: all ease-out .2s;
}

.oceanwp-instagram-follow span {
    display: inline-block;
    padding: 4px 6px;
    font-size: 10px;
    line-height: 1;
    text-transform: uppercase;
    background-color: #47bc60;
    background-image: -webkit-gradient(linear,left top,left bottom,from(#47bc60),to(#39a64e));
    background-image: -webkit-linear-gradient(top,#47bc60,#39a64e);
    background-image: -moz-linear-gradient(top,#47bc60,#39a64e);
    background-image: -o-linear-gradient(top,#47bc60,#39a64e);
    background-image: -ms-linear-gradient(top,#47bc60,#39a64e);
    background-image: linear-gradient(top,#47bc60,#39a64e);
    filter: progid:DXImageTransform.Microsoft.gradient(GradientType=0,StartColorStr='#47bc60',EndColorStr='#39a64e');
    color: #fff;
    border: 1px solid #329345;
    text-shadow: 0 1px 1px #2c803c;
    -webkit-border-radius: 3px;
    -moz-border-radius: 3px;
    border-radius: 3px;
}

.oceanwp-instagram-avatar a:hover .oceanwp-instagram-follow {
    top: 50%;
    opacity: 1;
}

/*header info*/
.oceanwp-instagram-info .oceanwp-instagram-username {
    display: block;
    font-size: 16px;
    font-weight: 600;
    line-height: 1.3;
    margin: 0 0 4px;
    text-transform: capitalize;
}

.oceanwp-instagram-info .oceanwp-instagram-desc {
    display: block;
    line-height: 1.3;
    margin: 0;
}

/*style 1*/
.oceanwp-instagram-pics.style-one li:first-child {
    width: 100%;
}

.oceanwp-instagram-pics.style-one li {
    width: 33.33%;
}

/*style 2*/
.oceanwp-instagram-pics.style-two li:nth-child(1),
.oceanwp-instagram-pics.style-two li:nth-child(2) {
    width: 50%;
}

.oceanwp-instagram-pics.style-two li {
    width: 25%;
}

/*style 3*/
.oceanwp-instagram-pics.style-three li:nth-child(4n+1) {
    width: 100%;
}

.oceanwp-instagram-pics.style-three li {
    width: 33.33%;
}

/*style 4*/
.oceanwp-style-four-wrap {
    background: #f6f6f6;
    border-bottom: 3px solid #eee;
    -webkit-border-radius: 3px;
    -moz-border-radius: 3px;
    border-radius: 3px;
}

.oceanwp-instagram-bar {
    background-color: #6f97b6;
    background-image: -webkit-gradient(linear,left top,left bottom,from(#6f97b6),to(#3f729b));
    background-image: -webkit-linear-gradient(top,#6f97b6,#3f729b);
    background-image: -moz-linear-gradient(top,#6f97b6,#3f729b);
    background-image: -ms-linear-gradient(top,#6f97b6,#3f729b);
    background-image: -o-linear-gradient(top,#6f97b6,#3f729b);
    background-image: linear-gradient(top,#6f97b6,#3f729b);
    filter: progid:DXImageTransform.Microsoft.gradient(GradientType=0,StartColorStr='#6f97b6',EndColorStr='#3f729b');
    border-top-left-radius: 3px;
    border-top-right-radius: 3px;
    overflow: hidden;
}

.oceanwp-instagram-bar .instagram-logo {
    display: block;
    margin: 8px auto 6px;
    width: 96px;
    height: 29px;
    background: url( '../../assets/img/instagram-logo.png' ) no-repeat;
}

.oceanwp-style-four-wrap .oceanwp-instagram-header {
    background-color: #fff;
    padding: 20px 15px;
    border-left-width: 1px;
    border-right-width: 1px;
    border-bottom-width: 1px;
    border-style: solid;
    border-color: #eaeaea;
}

.oceanwp-style-four-wrap .oceanwp-instagram-header.oceanwp-after {
    border-top: 1px solid #eaeaea;
    margin-bottom: 10px;
}

.oceanwp-instagram-pics.style-four.margin li img {
    padding: 3px;
    background: #fff;
    -webkit-box-shadow: 0 0 0 1px rgba(0,0,0,.04),0 1px 5px rgba(0,0,0,.1);
    -moz-box-shadow: 0 0 0 1px rgba(0,0,0,.04),0 1px 5px rgba(0,0,0,.1);
    box-shadow: 0 0 0 1px rgba(0,0,0,.04),0 1px 5px rgba(0,0,0,.1);
}

.oceanwp-instagram-pics.style-four {
    padding: 10px;
    border-left-width: 1px;
    border-right-width: 1px;
    border-style: solid;
    border-color: #eaeaea;
}

.oceanwp-instagram-pics.style-four li {
    width: 33.33%;
}

/*two columns*/
.oceanwp-instagram-pics.two-columns li {
    width: 50%;
}

/*three columns*/
.oceanwp-instagram-pics.three-columns li {
    width: 33.33%;
}

/*four columns*/
.oceanwp-instagram-pics.four-columns li {
    width: 25%;
}

/*five columns*/
.oceanwp-instagram-pics.five-columns li {
    width: 20%;
}

/*six columns*/
.oceanwp-instagram-pics.six-columns li {
    width: 16.66%;
}

/*seven columns*/
.oceanwp-instagram-pics.seven-columns li {
    width: 14.28%;
}

/*eight columns*/
.oceanwp-instagram-pics.eight-columns li {
    width: 12.5%;
}

/*nine columns*/
.oceanwp-instagram-pics.nine-columns li {
    width: 11.11%;
}

/*ten columns*/
.oceanwp-instagram-pics.ten-columns li {
    width: 10%;
}

/*link*/
.oceanwp-instagram-link {
    display: block;
    margin: 10px 0 0;
    text-align: center;
}

.oceanwp-instagram-link a {
    display: inline-block;
    font-size: 12px;
    line-height: 1.2;
    letter-spacing: 0.8px;
    padding: 0 0 3px;
    border-bottom: 1px solid;
    text-transform: uppercase;
}

/*style four link*/
.oceanwp-style-four-wrap .oceanwp-instagram-link {
    padding: 3px 0 16px;
    margin: 0;
    border-left-width: 1px;
    border-right-width: 1px;
    border-style: solid;
    border-color: #eaeaea;
}

.oceanwp-style-four-wrap .oceanwp-instagram-link a {
    display: block;
    background-color: #5582A7;
    color: #fff;
    padding: 12px 8px;
    margin: 0 auto;
    font-weight: 600;
    border: 0;
    width: 80%;
    max-width: 300px;
    -webkit-border-radius: 5px;
    -moz-border-radius: 5px;
    border-radius: 5px;
    -webkit-box-shadow: 0 0 0 1px rgba(0,0,0,0.04),0 1px 3px rgba(0,0,0,0.1);
    -moz-box-shadow: 0 0 0 1px rgba(0,0,0,0.04),0 1px 3px rgba(0,0,0,0.1);
    box-shadow: 0 0 0 1px rgba(0,0,0,0.04),0 1px 3px rgba(0,0,0,0.1);
}

.oceanwp-style-four-wrap .oceanwp-instagram-link a:hover {
    background-color: #3f729b;
    color: #fff;
}