/**
 * Tags Widget
 */
.tagcloud a {
	display: inline-block;
    background-color: $color-8;
    color: $color-2;
    border: 1px solid $border-color;
    font-size: 12px !important;
    line-height: 1;
    padding: 8px 12px;
    margin: 0 2px 5px 0;
    letter-spacing: 0.4px;
    text-transform: uppercase;

    &:hover {
	    background-color: $color-9;
	    color: $color-2;
	    border-color: $color-10;
	}
}