/**
 * Social Icons Widget
 */
.oceanwp-social-icons {
	display: inline-block;
	width: 100%;
	list-style: none;
	margin: 0;
	padding: 0;

	&.rotate a:hover {
		transform: rotate(360deg);
	}

	&.zoomout a:hover {
		transform: scale(0.8);
	}

	&.float a:hover {
		transform: translateY(-3px);
	}

	li {
	    display: inline-block;
		margin: 3px;
		padding: 0;

		a {
		    display: block;
		    padding: 0;
		    text-align: center;
		}

		.owp-icon {
			vertical-align: inherit;
		}
	}

	&.style-light li a,
	&.style-dark li a,
	&.style-colored li a {
	    width: 55px;
	    height: 55px;
	    line-height: 55px;
	    font-size: 16px;
		border-radius: 2px;
	}

	&.style-light li {
		a {
		    color: $color-13;
		    border: 1px solid $border-color;

			.owp-icon use {
				stroke: $color-13;
			}
		}

		&.oceanwp-twitter a:hover { color: #46d4fe !important; border-color: #46d4fe !important; }
		&.oceanwp-twitter a:hover .owp-icon use { stroke: #46d4fe !important; }
		&.oceanwp-facebook a:hover { color: #37589b !important; border-color: #37589b !important; }
		&.oceanwp-facebook a:hover .owp-icon use { stroke: #37589b !important; }
		&.oceanwp-pinterest a:hover { color: #cb2027 !important; border-color: #cb2027 !important; }
		&.oceanwp-pinterest a:hover .owp-icon use { stroke: #cb2027 !important; }
		&.oceanwp-dribbble a:hover { color: #ea4c89 !important; border-color: #ea4c89 !important; }
		&.oceanwp-dribbble a:hover .owp-icon use { stroke: #ea4c89 !important; }
		&.oceanwp-vk a:hover { color: #597BA5 !important; border-color: #597BA5 !important; }
		&.oceanwp-vk a:hover .owp-icon use { stroke: #597BA5 !important; }
		&.oceanwp-instagram a:hover { color: #3F729B !important; border-color: #3F729B !important; }
		&.oceanwp-instagram a:hover .owp-icon use { stroke: #3F729B !important; }
		&.oceanwp-linkedin a:hover { color: #3399CC !important; border-color: #3399CC !important; }
		&.oceanwp-linkedin a:hover .owp-icon use { stroke: #3399CC !important; }
		&.oceanwp-tumblr a:hover { color: #2C4762 !important; border-color: #2C4762 !important; }
		&.oceanwp-tumblr a:hover .owp-icon use { stroke: #2C4762 !important; }
		&.oceanwp-github a:hover { color: #60b044 !important; border-color: #60b044 !important; }
		&.oceanwp-github a:hover .owp-icon use { stroke: #60b044 !important; }
		&.oceanwp-flickr a:hover { color: #fa4086 !important;border-color: #fa4086 !important; }
		&.oceanwp-flickr a:hover .owp-icon use { stroke: #fa4086 !important; }
		&.oceanwp-skype a:hover { color: #00AFF0 !important; border-color: #00AFF0 !important; }
		&.oceanwp-skype a:hover .owp-icon use { stroke: #00AFF0 !important; }
		&.oceanwp-trello a:hover { color: #0079bf !important; border-color: #0079bf !important; }
		&.oceanwp-trello a:hover .owp-icon use { stroke: #0079bf !important; }
		&.oceanwp-foursquare a:hover { color: #2d5be3 !important; border-color: #2d5be3 !important; }
		&.oceanwp-foursquare a:hover .owp-icon use { stroke: #2d5be3 !important; }
		&.oceanwp-youtube a:hover { color: #C4302B !important; border-color: #C4302B !important; }
		&.oceanwp-youtube a:hover .owp-icon use { stroke: #C4302B !important; }
		&.oceanwp-vimeo a:hover { color: #1ab7ea !important; border-color: #1ab7ea !important; }
		&.oceanwp-vimeo a:hover .owp-icon use { stroke: #1ab7ea !important; }
		&.oceanwp-vine a:hover { color: #00bf8f !important; border-color: #00bf8f !important; }
		&.oceanwp-vine a:hover .owp-icon use { stroke: #00bf8f !important; }
		&.oceanwp-xing a:hover { color: #006464 !important; border-color: #006464 !important; }
		&.oceanwp-xing a:hover .owp-icon use { stroke: #006464 !important; }
		&.oceanwp-yelp a:hover { color: #C41200 !important; border-color: #C41200 !important; }
		&.oceanwp-yelp a:hover .owp-icon use { stroke: #C41200 !important; }
		&.oceanwp-tripadvisor a:hover { color: #589442 !important; border-color: #589442 !important; }
		&.oceanwp-tripadvisor a:hover .owp-icon use { stroke: #589442 !important; }
		&.oceanwp-rss a:hover { color: #ff7900 !important; border-color: #ff7900 !important; }
		&.oceanwp-rss a:hover .owp-icon use { stroke: #ff7900 !important; }
		&.oceanwp-email a:hover { color: #13aff0 !important; border-color: #13aff0 !important; }
		&.oceanwp-email a:hover .owp-icon use { stroke: #13aff0 !important; }
		&.oceanwp-telegram a:hover { color: #0088cc !important; border-color: #0088cc !important; }
		&.oceanwp-telegram a:hover .owp-icon use { stroke: #0088cc !important; }
		&.oceanwp-twitch a:hover { color: #6441a5 !important; border-color: #6441a5 !important; }
		&.oceanwp-twitch a:hover .owp-icon use { stroke: #6441a5 !important; }
		&.oceanwp-line a:hover { color: #00c300 !important; border-color: #00c300 !important; }
		&.oceanwp-line a:hover .owp-icon use { stroke: #00c300 !important; }
		&.oceanwp-medium a:hover { color: #00ab6c !important; border-color: #00ab6c !important; }
		&.oceanwp-medium a:hover .owp-icon use { stroke: #00ab6c !important; }
		&.oceanwp-tiktok a:hover { color: #000000 !important; border-color: #000000 !important; }
		&.oceanwp-tiktok a:hover .owp-icon use { stroke: #000000 !important; }
		&.oceanwp-vk a:hover { color: #597BA5 !important; border-color: #597BA5 !important; }
		&.oceanwp-vk a:hover .owp-icon use { stroke: #597BA5 !important; }
	}

	&.style-dark li {
		a {
		    color: $color-2;
		    border: 1px solid $color-2;

			.owp-icon use {
				stroke: $color-2;
			}
		}

		&.oceanwp-twitter a:hover { color: #46d4fe !important; border-color: #46d4fe !important; }
		&.oceanwp-twitter a:hover .owp-icon use { stroke: #46d4fe !important; }
		&.oceanwp-facebook a:hover { color: #37589b !important; border-color: #37589b !important; }
		&.oceanwp-facebook a:hover .owp-icon use { stroke: #37589b !important; }
		&.oceanwp-pinterest a:hover { color: #cb2027 !important; border-color: #cb2027 !important; }
		&.oceanwp-pinterest a:hover .owp-icon use { stroke: #cb2027 !important; }
		&.oceanwp-dribbble a:hover { color: #ea4c89 !important; border-color: #ea4c89 !important; }
		&.oceanwp-dribbble a:hover .owp-icon use { stroke: #ea4c89 !important; }
		&.oceanwp-vk a:hover { color: #597BA5 !important; border-color: #597BA5 !important; }
		&.oceanwp-vk a:hover .owp-icon use { stroke: #597BA5 !important; }
		&.oceanwp-instagram a:hover { color: #3F729B !important; border-color: #3F729B !important; }
		&.oceanwp-instagram a:hover .owp-icon use { stroke: #3F729B !important; }
		&.oceanwp-linkedin a:hover { color: #3399CC !important; border-color: #3399CC !important; }
		&.oceanwp-linkedin a:hover .owp-icon use { stroke: #3399CC !important; }
		&.oceanwp-tumblr a:hover { color: #2C4762 !important; border-color: #2C4762 !important; }
		&.oceanwp-tumblr a:hover .owp-icon use { stroke: #2C4762 !important; }
		&.oceanwp-github a:hover { color: #60b044 !important; border-color: #60b044 !important; }
		&.oceanwp-github a:hover .owp-icon use { stroke: #60b044 !important; }
		&.oceanwp-flickr a:hover { color: #fa4086 !important;border-color: #fa4086 !important; }
		&.oceanwp-flickr a:hover .owp-icon use { stroke: #fa4086 !important; }
		&.oceanwp-skype a:hover { color: #00AFF0 !important; border-color: #00AFF0 !important; }
		&.oceanwp-skype a:hover .owp-icon use { stroke: #00AFF0 !important; }
		&.oceanwp-trello a:hover { color: #0079bf !important; border-color: #0079bf !important; }
		&.oceanwp-trello a:hover .owp-icon use { stroke: #0079bf !important; }
		&.oceanwp-foursquare a:hover { color: #2d5be3 !important; border-color: #2d5be3 !important; }
		&.oceanwp-foursquare a:hover .owp-icon use { stroke: #2d5be3 !important; }
		&.oceanwp-youtube a:hover { color: #C4302B !important; border-color: #C4302B !important; }
		&.oceanwp-youtube a:hover .owp-icon use { stroke: #C4302B !important; }
		&.oceanwp-vimeo a:hover { color: #1ab7ea !important; border-color: #1ab7ea !important; }
		&.oceanwp-vimeo a:hover .owp-icon use { stroke: #1ab7ea !important; }
		&.oceanwp-vine a:hover { color: #00bf8f !important; border-color: #00bf8f !important; }
		&.oceanwp-vine a:hover .owp-icon use { stroke: #00bf8f !important; }
		&.oceanwp-xing a:hover { color: #006464 !important; border-color: #006464 !important; }
		&.oceanwp-xing a:hover .owp-icon use { stroke: #006464 !important; }
		&.oceanwp-yelp a:hover { color: #C41200 !important; border-color: #C41200 !important; }
		&.oceanwp-yelp a:hover .owp-icon use { stroke: #C41200 !important; }
		&.oceanwp-tripadvisor a:hover { color: #589442 !important; border-color: #589442 !important; }
		&.oceanwp-tripadvisor a:hover .owp-icon use { stroke: #589442 !important; }
		&.oceanwp-rss a:hover { color: #ff7900 !important; border-color: #ff7900 !important; }
		&.oceanwp-rss a:hover .owp-icon use { stroke: #ff7900 !important; }
		&.oceanwp-email a:hover { color: #13aff0 !important; border-color: #13aff0 !important; }
		&.oceanwp-email a:hover .owp-icon use { stroke: #13aff0 !important; }
		&.oceanwp-telegram a:hover { color: #0088cc !important; border-color: #0088cc !important; }
		&.oceanwp-telegram a:hover .owp-icon use { stroke: #0088cc !important; }
		&.oceanwp-twitch a:hover { color: #6441a5 !important; border-color: #6441a5 !important; }
		&.oceanwp-twitch a:hover .owp-icon use { stroke: #6441a5 !important; }
		&.oceanwp-line a:hover { color: #00c300 !important; border-color: #00c300 !important; }
		&.oceanwp-line a:hover .owp-icon use { stroke: #00c300 !important; }
		&.oceanwp-medium a:hover { color: #00ab6c !important; border-color: #00ab6c !important; }
		&.oceanwp-medium a:hover .owp-icon use { stroke: #00ab6c !important; }
		&.oceanwp-tiktok a:hover { color: #000000 !important; border-color: #000000 !important; }
		&.oceanwp-tiktok a:hover .owp-icon use { stroke: #000000 !important; }
		&.oceanwp-vk a:hover { color: #597BA5 !important; border-color: #597BA5 !important; }
		&.oceanwp-vk a:hover .owp-icon use { stroke: #597BA5 !important; }
	}

	&.style-colored li {
		a {
		    color: $color-1;

			.owp-icon use {
				stroke: $color-1;
			}

		    &:hover {
		    	color: $color-1;

				.owp-icon use {
					stroke: $color-1;
				}
		    }
		}

		&.oceanwp-twitter a { background-color: #46d4fe; }
		&.oceanwp-twitter a:hover { background-color: #39b4d8; }
		&.oceanwp-facebook a { background-color: #37589b; }
		&.oceanwp-facebook a:hover{ background-color: #2d477c; }
		&.oceanwp-pinterest a { background-color: #cb2027; }
		&.oceanwp-pinterest a:hover { background-color: #a91d23; }
		&.oceanwp-dribbble a { background-color: #ea4c89; }
		&.oceanwp-dribbble a:hover { background-color: #c64174; }
		&.oceanwp-vk a { background-color: #597BA5; }
		&.oceanwp-vk a:hover { background-color: #486384; }
		&.oceanwp-instagram a { background-color: #3F729B; }
		&.oceanwp-instagram a:hover { background-color: #315a7c; }
		&.oceanwp-linkedin a { background-color: #3399CC; }
		&.oceanwp-linkedin a:hover { background-color: #2678a1; }
		&.oceanwp-tumblr a { background-color: #2C4762; }
		&.oceanwp-tumblr a:hover { background-color: #1d3042; }
		&.oceanwp-github a { background-color: #60b044; }
		&.oceanwp-github a:hover { background-color: #4f9237; }
		&.oceanwp-flickr a { background-color: #fa4086; }
		&.oceanwp-flickr a:hover { background-color: #c63169; }
		&.oceanwp-skype a { background-color: #00AFF0; }
		&.oceanwp-skype a:hover { background-color: #0291c6; }
		&.oceanwp-trello a { background-color: #0079bf; }
		&.oceanwp-trello a:hover { background-color: #0079bf; }
		&.oceanwp-foursquare a { background-color: #2d5be3; }
		&.oceanwp-foursquare a:hover { background-color: #2d5be3; }
		&.oceanwp-youtube a { background-color: #C4302B; }
		&.oceanwp-youtube a:hover { background-color: #982420; }
		&.oceanwp-vimeo a { background-color: #1ab7ea; }
		&.oceanwp-vimeo a:hover { background-color: #1494bd; }
		&.oceanwp-vine a { background-color: #00bf8f; }
		&.oceanwp-vine a:hover { background-color: #01906c; }
		&.oceanwp-xing a { background-color: #006464; }
		&.oceanwp-xing a:hover { background-color: #014646; }
		&.oceanwp-yelp a { background-color: #C41200; }
		&.oceanwp-yelp a:hover { background-color: #940f01; }
		&.oceanwp-tripadvisor a { background-color: #589442; }
		&.oceanwp-tripadvisor a:hover { background-color: #426f32; }
		&.oceanwp-rss a { background-color: #ff7900; }
		&.oceanwp-rss a:hover { background-color: #d46603; }
		&.oceanwp-email a { background-color: #13aff0; }
		&.oceanwp-email a:hover { background-color: #0f8dc2; }
		&.oceanwp-telegram a { background-color: #0088cc; }
		&.oceanwp-telegram a:hover { background-color: #0088cc; }
		&.oceanwp-twitch a { background-color: #6441a5; }
		&.oceanwp-twitch a:hover { background-color: #6441a5; }
		&.oceanwp-line a { background-color: #00c300; }
		&.oceanwp-line a:hover { background-color: #00c300; }
		&.oceanwp-medium a { background-color: #00ab6c; }
		&.oceanwp-medium a:hover { background-color: #00ab6c; }
		&.oceanwp-tiktok a { background-color: #000000; }
		&.oceanwp-tiktok a:hover { background-color: #000000; }
		&.oceanwp-vk a { background-color: #597BA5; }
		&.oceanwp-vk a:hover { background-color: #597BA5; }
	}

	&.style-simple li {
		margin: 0 6px;

	    a {
		    font-size: 16px;
		}
	}
}